@@ -4,16 +4,16 @@ This module is used to:
 
 
 如果需要使用 dataSet(目前只支持CSV格式）,请按照如下方式定义：
-    1. 定义一个 csv文件，该文件中必须包含id列
+    1. 定义一个 csv文件, 必须使用","作为分隔符
     2. 在csv文件的同级目录下定义一个 和csv文件同名的.py文件，py文件中必须定义一个 run_test(self, param...)方法
     参考如下：
        1. testLogin.csv 文件如下：
-           id,channel,username,password
-            1,web,"admin1","admin1"
-            2,web,admin2,"admin2"
-            3,web,user1,user2
-            4,app,admin1,admin1
-            5,app,admin2,admin2
+           channel,username,password
+            web,"admin1","admin1"
+            web,admin2,"admin2"
+            web,user1,user2
+            app,admin1,admin1
+            app,admin2,admin2
 
        2. testLogin.py文件内容如下：
             from common.test_login import login # 引入的具体业务逻辑处理方法
@@ -93,7 +93,7 @@ PROJECT_INFO = get_project_info.get_project_info()
 TESTS_PACKAGE_PATH = PROJECT_INFO.project_path + os.sep + PROJECT_INFO.testcase_package_name
 
 
-def generate_testcase_list_by_csv(file_name, row, is_ui_testcase, tag_name=''):
+def generate_testcase_list_by_csv(file_name, row, index, is_ui_testcase, tag_name=''):
     py_file_name = file_name.split(".")[0] + ".py"
 
     # 先 解析 py 文件,检测 文件中是否包含 def run_test(self, param1, param2 ...) 方法定义， 否则提示用户必须按照这种规范来写 dataSet（csv)的testcase
@@ -111,16 +111,16 @@ def generate_testcase_list_by_csv(file_name, row, is_ui_testcase, tag_name=''):
             errInfo = """
             %s 文件 不符合如下规范！ 请检查更新后重新运行！
             如果需要使用 dataSet(目前只支持CSV格式）,请按照如下方式定义：
-            1. 定义一个 csv文件，该文件中必须包含id列
+            1. 定义一个 csv文件, 并且必须以","作为分隔符
             2. 在csv文件的同级目录下定义一个 和csv文件同名的.py文件，py文件中必须定义一个 run_test(self, param...)方法
             参考如下：
                1. testLogin.csv 文件如下：
-                   id,channel,username,password
-                    1,web,"admin1","admin1"
-                    2,web,admin2,"admin2"
-                    3,web,user1,user2
-                    4,app,admin1,admin1
-                    5,app,admin2,admin2
+                   channel,username,password
+                    web,"admin1","admin1"
+                    web,admin2,"admin2"
+                    web,user1,user2
+                    app,admin1,admin1
+                    app,admin2,admin2
                     
                2. testLogin.py文件内容如下：
                     from common.test_login import login # 引入的具体业务逻辑处理方法
@@ -202,9 +202,9 @@ def generate_testcase_list_by_csv(file_name, row, is_ui_testcase, tag_name=''):
                 class_name = py_file_name.split(".")[0].split(os.sep)[-1]
                 # class_name = "".join(class_name[:1].upper() + class_name[1:]) # todo: 讨论是否需要把clasName首字母转成大写？
                 if is_ui_testcase:
-                    new_file_lines.append("\n\n\nclass %s_%s(UITestCase):\n" % (class_name, row["id"]))
+                    new_file_lines.append("\n\n\nclass %s_%s(UITestCase):\n" % (class_name, index))
                 else:
-                    new_file_lines.append("\n\n\nclass %s_%s(APITestCase):\n" % (class_name, row["id"]))
+                    new_file_lines.append("\n\n\nclass %s_%s(APITestCase):\n" % (class_name, index))
                 new_file_lines.append('    tag = "%s, %s"\n\n' % (class_name, tag_name))
                 param_list = line.replace(" ", "").split("self,")[1].split(")")[0].split(",")
                 line = "    def run_test(self):"
@@ -262,16 +262,16 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
                         print("py文件:%s 格式不符合要求! --- 不会自动生成对应的testcase文件" % file_name)
                         print("""
 如果需要使用 dataSet(目前只支持CSV格式）,请按照如下方式定义：
-    1. 定义一个 csv文件，该文件中必须包含id列
-    2. 在csv文件的同级目录下定义一个 和csv文件同名的.py文件，py文件中必须定义一个 run_test(self, param...)方法
+    1. 定义一个 csv文件，必须以","作为分隔符
+    2. 在csv文件的同级目录下定义一个和csv文件同名的.py文件, py文件中必须定义一个 run_test(self, param...)方法
     参考如下：
        1. testLogin.csv 文件如下：
-           id,channel,username,password
-            1,web,"admin1","admin1"
-            2,web,admin2,"admin2"
-            3,web,user1,user2
-            4,app,admin1,admin1
-            5,app,admin2,admin2
+           channel,username,password
+            web,"admin1","admin1"
+            web,admin2,"admin2"
+            web,user1,user2
+            app,admin1,admin1
+            app,admin2,admin2
 
        2. testLogin.py文件内容如下：
             from common.test_login import login # 引入的具体业务逻辑处理方法
@@ -339,8 +339,7 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
                         """)
                         break
 
-
-                    print(file_name + "存在对应的csv文件")
+                    # print(file_name + "存在对应的csv文件")
                     try:
                         os.remove(PROJECT_INFO.project_path + os.sep + directory_path + os.sep + file_name.split(".")[
                             0] + "_case_list_auto_generated_by_csv.py")
@@ -387,9 +386,12 @@ def auto_generate_testcase_list_from_csv(call_by_doctor=False):
 
                     with open(csv_file_full_path) as f:
                         f_csv = csv.DictReader(f)
+                        index = 0
+
                         for row in f_csv:
+                            index += 1
                             py_file_name = file_name.split(".")[0] + ".py"
-                            generate_testcase_list_by_csv(csv_file_full_path, row, is_ui_testcase, tag_name=tag_name)
+                            generate_testcase_list_by_csv(csv_file_full_path, row, index, is_ui_testcase, tag_name=tag_name)
 
 
 if __name__ == "__main__":
