@@ -46,15 +46,15 @@ def map_testcases_package(all_testcases_package, testcase_map_tag, testcase_filt
 
 class Reporter(object):
 
-    def __init__(self, output_folder, passed_cases, failed_cases, error_cases, start_time, platform_info, auto_refresh):
+    def __init__(self, output_folder, passed_cases, failed_cases, error_cases, start_time, platform_info, create_global_data_list_flag=False, auto_refresh=False):
         try:
             self.generate_html_report(output_folder, passed_cases, failed_cases, error_cases, start_time,
-                                      platform_info, auto_refresh)
+                                      platform_info, create_global_data_list_flag, auto_refresh)
         except BaseException:
             traceback.print_exc()
 
     def generate_html_report(self, output_folder, passed_cases, failed_cases, error_cases, start_time, platform_info,
-                             auto_refresh):
+                             create_global_data_list_flag, auto_refresh):
         with open(output_folder + os.sep + "report.html", "w") as report_file_handler:
             end_time = datetime.datetime.now()
             execution_time = end_time - start_time
@@ -308,13 +308,27 @@ class Reporter(object):
                     map_testcases_package(all_testcases_package, tc_map_tag, testcase_filter_tag, testcase)
 
             # generate the drop down list for all the different tags
-            html_drop_down_list = """
+            # 判断是不需要显示 'show Global Data List' button
+            if create_global_data_list_flag:
+                html_drop_down_list = """
+                            <div>
+                                <a style='margin-left: 72%%; margin-top: -20px;' class="btn btn-success" target='_blank' role='button'
+                                         href='%s'>Show Global Data</a>
+                            </div>
+                            <table border='0' align='center' width='950'>
+                                <tr>
+                                    <td width='285'><font style='color: black; font-size: 18; margin-left: -30'>Filter By Package: </font></td>
+                                    <td>
+                            """ % (output_folder + os.sep + "global_data_list.txt")
+            else:
+                html_drop_down_list = """
             <br>
             <table border='0' align='center' width='950'>
                 <tr>
                     <td width='285'><font style='color: black; font-size: 18; margin-left: -30'>Filter By Package: </font></td>
                     <td>
             """
+
             report_file_handler.write(html_drop_down_list)
 
             all_testcases_package_list = []
